# RapidEye and Landsat remote sensing measures for Sabah Biodiversity Experiment plots
---

Study system

The Sabah Biodiversity Experiment (http://www.sabahbiodiversityexperiment.org) occupies 500 ha in the southern part of the Malua Forest Reserve, in Sabah, Malaysian Borneo. The Malua Forest Reserve is an area of approximately 35,000 ha of predominantly selectively logged forest that is publicly owned through Yayasan Sabah (The Sabah Foundation), which as an experimental site has the goal of assessing the effect of species diversity on ecosystem functioning and services within a tropical forest setting. Visit the Sabah Biodiversity Experiment dedicated webpage for more information relating to it's design and methodology.

Study species

The 16 species used in this experiment are native species belonging to the Dipterocarpaceae: Dipterocarpus conformis Slooten, Dryobalanops lanceolata Burck, Hopea ferruginea Parij, Hopea sangal Korth., Parashorea malaanonan (Blanco) Merr., Parashorea tomentella (Blanco) Merr., Shorea argentifolia Sym., Shorea beccariana Bruck, Shorea faguetiana Heim., Shorea gibbosa Brandis., Shorea johorensis Foxw., Shorea leprosula Miq., Shorea macrophylla Ashton, Shorea macroptera King, Shorea ovalis Korth., and Shorea parvifolia Dyer.


## Description of the data and file structure

The structure of this dataset incorporates the key elements of the Sabah Biodiversity Experiment Study Design:

* Two blocks (north and south), separated by an old logging road [`Block`].

* 124 plots, each 4-ha (200 x 200 m) in size [`Plot`].

* Whether or not the plot was planted or left as an unplanted control [`Planting`].

* Each plot's associated planted species richness (between 0 (unplanted) and a 16-species mixture) [`Spp_richness`].

* A specific value corresponding to the combination of trees which were planted in each plot [`Spp_comp`]. 
  * The first number corresponds to the species richness (i.e 0, 1, 4, or 16 species)
  * The number following `_` provides more specific information:
    * For species richnesses of 0, this is just `0_unplanted`
    * For species richnesses of 1, the species planted is provided (e.g. `1_Shorea_beccariana`)
    * For species richnesses of 4, the specific combination is denoted by a number from 1 to 16 (e.g. `4_1`, see table S6 for corresponding species combinations).
    * For species richness of 16, information on if liana removal was performed (`16_cut`) or not (`16_spp`).

* If enhanced climber cutting was performed (a common management strategy in Sabah) [`Climber_cutting`].
  * Note: this treatment was only applied to a subset of the 16-species mixtures. Due to practical constraints, only the southern block had climber cutting treatments applied randomly, with northern block treatments determined by proximity to the road. As such an additional factor, `Random`, specifies if the treatment applies to each plot was done so randomly or not. 

* Each plot's generic diversity, ranging between 0 and 5 [`Gen_div`].
  * The focus here is on 4-species mixtures, which were either planted with a generic diversity of 2 or 4. There is no variation within any other level of species richness.

* The level of planted canopy complexity of the plot planted, measured in two ways:
  * Simple thick or thin combination of tree canopies [`Canopy_type`].
  * A more comprehensive breakdown of if the plot contains species with typically short, medium, and/or tall canopies (each option shortened to S, M, and T) [`Canopy_str`].

* Which of the 5 main plot-level treatments (unplanted controls, monocultures, 4-species polycultures, 16-species polycultures, and 16-species polycultures with enhanced climber cutting) each plot belongs to [`Treatment`].

For each plot six measurements are taken;

* Three Landsat vegetation cover measurements, covering each of the three time periods covered ('epochs').

* One RapidEye measurement each for vegetation cover, LAI, and estimated biomass.

And so the following additional columns are recorded:

* The satellite used (either RapidEye or Landsat satellites) [`Satellite`]

* What index was calculated using the corresponding satellite (either aboveground biomass, leaf area index, or canopy cover) [`Index`]

* The year the imagery was taken (note: these values are only given for Landsat, since all RapidEye imagery was taken at the same point in August 2012 and so do not vary) [`Year`].

* The value of the corresponding index [`Score`]

Finally, each dataset contains for columns representing calculated phylogenetic and functional diversity measures for each plot's planted species richness:

* Faith's PD [`PD`].
* Functional diversity (as calculated by `Petchy & Gaston (2002)`) [`FD`].

## Sharing/Access information

Data was derived from the following sources:
  * Heckenhauer, J., Samuel, R., Ashton, P. S., Turner, B., Barfuss, M. H., Jang, T. S., ... & Chase, M. W. (2017). Phylogenetic analyses of plastid DNA suggest a different interpretation of morphological evolution than those used as the basis for previous classifications of Dipterocarpaceae (Malvales). Botanical Journal of the Linnean Society, 185(1), 1-26.
  * Cvetković, T., Hinsinger, D. D., Thomas, D. C., Wieringa, J. J., Velautham, E., & Strijk, J. S. (2022). Phylogenomics and a revised tribal classification of subfamily Dipterocarpoideae (Dipterocarpaceae). Taxon, 71(1), 85-102.
  * Petchey, O. L., & Gaston, K. J. (2002). Functional diversity (FD), species richness and community composition. Ecology letters, 5(3), 402-411.
  * Wu, J., Chen, B., Reynolds, G., Xie, J., Liang, S., O'Brien, M. J., & Hector, A. (2020). Monitoring tropical forest degradation and restoration with satellite remote sensing: A test using Sabah Biodiversity Experiment. In Advances in ecological research (Vol. 62, pp. 117-146). Academic Press.


## Code/Software

This data was analysed predominantly using linear mixed effect models with the lme4 (version 1.1-26) and lmerTest (version 3.1-3) packages for R (version 4.0.5). 